**copy** - Copy a profile
=================================

Usage
------

.. code::

    e4s-cl profile copy <NAME> <NEW NAME>

Description
-------------

.. automodule:: e4s_cl.cli.commands.profile.copy
